{-# OPTIONS -#include "cpicture_121.h" #-}

-- #hide
-----------------------------------------------------------------------------
-- |
-- Module      :  OS.Rgn
-- Copyright   :  (c) Krasimir Andreev 2002
-- License     :  BSD-style
-- 
-- Maintainer  :  ka2_mail@yahoo.com
-- Stability   :  provisional
-- Portability :  portable
--
-- OS.Rgn contains OS operations to manage regions.
--
-----------------------------------------------------------------------------

module Graphics.UI.ObjectIO.OS.Rgn
		( OSRgnHandle
		, osNewRgn, osNewRectRgn, osDisposeRgn, osPolyRgn
		, osSectRgn, osUnionRgn, osDiffRgn, osXorRgn
		, osGetRgnBox, osIsEmptyRgn, osNoRgn
		) where



import Graphics.UI.ObjectIO.OS.Types
import Graphics.UI.ObjectIO.OS.PictCCall_12
import Graphics.UI.ObjectIO.OS.RgnCCall_12
import Foreign.Ptr(Ptr(..), nullPtr)


type	OSRgnHandle
	= Ptr ()
type	OSPointH
	= Ptr Int

osNoRgn = nullPtr

--	Region creation and disposal operations.
osNewRgn :: IO OSRgnHandle
osNewRgn = winCreateEmptyRgn

osNewRectRgn :: Rect -> IO OSRgnHandle
osNewRectRgn (Rect {rleft=rleft,rtop=rtop,rright=rright,rbottom=rbottom})
	= winCreateRectRgn rleft rtop rright rbottom

osPolyRgn :: (Int,Int) -> [(Int,Int)] -> IO OSRgnHandle
osPolyRgn base shape
	= do {		
		if   len==0
		then winCreateEmptyRgn
		else 
		do {
			shapeH <- winAllocPolyShape len;
			setPolyShape shapeH 0 base shape;
			prgn   <- winCreatePolygonRgn shapeH len winding;
			winFreePolyShape shapeH;
			return prgn
		}
	  }
	where
		len = length shape
		
		setPolyShape :: OSPointH -> Int -> (Int,Int) -> [(Int,Int)] -> IO ()
		setPolyShape shapeH i (x,y) ((vx,vy):vs)
			= winSetPolyPoint i x y shapeH >> setPolyShape shapeH (i+1) (x+vx,y+vy) vs
		setPolyShape _ _ _ _ = return ()
		
osDisposeRgn :: OSRgnHandle -> IO ()
osDisposeRgn = winDisposeRgn


--	Combining the shapes of two Regions into a new Region.
osSectRgn :: OSRgnHandle -> OSRgnHandle -> IO OSRgnHandle
osSectRgn = winSectRgn

osUnionRgn :: OSRgnHandle -> OSRgnHandle -> IO OSRgnHandle
osUnionRgn = winUnionRgn

osDiffRgn :: OSRgnHandle -> OSRgnHandle -> IO OSRgnHandle
osDiffRgn = winDiffRgn

osXorRgn :: OSRgnHandle -> OSRgnHandle -> IO OSRgnHandle
osXorRgn = winXorRgn


--	Region property access functions.
osGetRgnBox :: OSRgnHandle -> IO (Bool,Rect)
osGetRgnBox rgn = do
	(l,t,r,b,isRect) <- winGetRgnBox rgn
	return (isRect,Rect {rleft=l,rtop=t,rright=r,rbottom=b})

osIsEmptyRgn :: OSRgnHandle -> IO Bool
osIsEmptyRgn = winIsEmptyRgn
